/*
	Copyright (C) 2016 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.custom;

import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Example action factory for creating actions
	for the custom extension point 
	"net.sf.basedb.examples.extensions.custom-extension-point".
	
	@author nicklas
	@since 1.8
*/
public class ExampleActionFactory
	implements ActionFactory<ExampleAction>
{

	private String name;
	
	// A public, no-argument constructor is required
	public ExampleActionFactory()
	{}
   
	// Return true enable the extension, false to disable it
	@Override
	public boolean prepareContext(InvokationContext<? super ExampleAction> context) 
	{
		return true;
	}

	// An extension may create one or more actions
	@Override
	public ExampleAction[] getActions(InvokationContext<? super ExampleAction> context) 
	{
		ExampleAction[] actions = new ExampleAction[1];
		actions[0] = new ExampleAction() 
		{
			@Override
			public String getName() 
			{
				return name;
			}
		};
		return actions;
	}
	
	/**
		Set the name of the example action.
	*/
	public void setName(String name)
	{
		this.name = name;
	}

}
