/*
	Copyright (C) 2011 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.menu;

import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.extensions.menu.MenuItemAction;
import net.sf.basedb.clients.web.extensions.menu.MenuItemBean;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	First example of an action factory where eveything is hardcoded.
	@author nicklas
*/
public class HelloWorldFactory
	implements ActionFactory<MenuItemAction>
{

	// The ID attribute of the <div> tag in the final HTML
	private String id;
	
	private MenuItemAction[] helloWorld;

	// A public, no-argument constructor is required
	public HelloWorldFactory()
	{
		helloWorld = new MenuItemAction[1];
	}
   
	// Return true enable the extension, false to disable it
	@Override
	public boolean prepareContext(InvokationContext<? super MenuItemAction> context) 
	{
		return true;
	}

	// An extension may create one or more actions
	@Override
	public MenuItemAction[] getActions(InvokationContext<? super MenuItemAction> context) 
	{
		// This cast is always safe with the web client
		JspContext jspContext = (JspContext)context.getClientContext();
		if (helloWorld[0] == null)
		{
			MenuItemBean bean = new MenuItemBean();
			bean.setId(id);
			bean.setMenuId("hello");
			bean.setTitle("Hello factory world!");
			bean.setIcon(jspContext.getHome(context.getExtension()) + "/images/factory.png");
			helloWorld[0] = bean;
		}
		return helloWorld;
	}
	
	/**
		Set the ID to use for the <div> tag. This is needed
		so that we can attach a 'click' handler to the menu item
		with JavaScript (see examples.jsp)
	*/
	public void setId(String id)
	{
		this.id = id;
	}

}
