/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Ownable;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.User;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.extensions.ChildNodeLoaderAction;
import net.sf.basedb.util.overview.loader.BasicItemNodeLoader;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation that load the owner of an item as a property 
	node. It can't be a root node or a forward/reverse-loading node.
	We extend from the {@link BasicItemNodeLoader} class to be able to take
	advantage of already implemented functionality in the BASE core.
	
	@author Nicklas
	@since 1.5
*/
public class OwnerNodeLoader
	extends BasicItemNodeLoader<User>
	implements ChildNodeLoaderAction
{

	public OwnerNodeLoader()
	{
		super(Item.USER, DENY_ROOT_NODE, 
				new NameableNameGenerator<User>("owner", "Owner"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		NodeFactory<User> nf = getNodeFactory(dc, context);
		User owner = null;
		boolean denied = false;
		try
		{
			// We know that the parent item is an Ownable item since that 
			// was checked by the OwnerNodeLoaderFactory
			Ownable parentItem = (Ownable)parentNode.getItem(dc);
			owner = parentItem.getOwner();
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		// Use the superclass functionality to create the owner node
		// It will take care of validation options and more automatically
		Node ownerNode = createItemNode(nf, owner, owner, denied, 
				parentNode, ChildNodeDirection.PROPERTY);
		return ownerNode;
	}
	// -----------------------------------

	/*
		From the ChildNodeLoaderAction
		------------------------------
	*/
	@Override
	public void createChildNodes(DbControl dc, OverviewContext context, Node parentNode) 
	{
		createPropertyNode(dc, context, parentNode);
	}
	// -------------------------------
	
}
