/*
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.User;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.overview.extensions.NodeValidatorAction;

/**
	Example action factory that create actions for validating nodes
	that represent User items.
	
	@author nicklas
	@since 1.5
*/
public class OwnerValidatorFactory
	implements ActionFactory<NodeValidatorAction<User>>
{

	/**
	 	A public, no-argument constructor is required
	*/
	public OwnerValidatorFactory()
	{}
   
	/**
		Return true to enable the extension, false to disable it. This extension is enabled
		if the current item is {@link Item#USER}. Note that validators are created before
		nodes, so there is no information about the specific node or item it contains
		at this moment.
	*/
	@Override
	public boolean prepareContext(InvokationContext<? super NodeValidatorAction<User>> context) 
	{
		return context.getClientContext().getCurrentItem() == Item.USER;
	}

	/**
		Create the {@link OwnerValidator} action.
	*/
	@SuppressWarnings("unchecked")
	@Override
	public NodeValidatorAction<User>[] getActions(InvokationContext<? super NodeValidatorAction<User>> context) 
	{
		return new NodeValidatorAction[] { new OwnerValidator() };
	}
}
