/*
	Copyright (C) 2016 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.servlet;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.clients.web.extensions.ExtensionsControl;
import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.examples.extensions.custom.ExampleAction;
import net.sf.basedb.util.extensions.ExtensionsInvoker;

/**
	Servlet for listing all extensions to the 
	"net.sf.basedb.examples.extensions.custom-extension-point" 
	extension point.
	
	@author nicklas
	@since 1.8
*/
public class ListExampleActions 
	extends HttpServlet 
{

	private static final long serialVersionUID = 8926040686494484870L;
	private String template;
	
	public ListExampleActions()
	{}

	@SuppressWarnings("unchecked")
	@Override
	protected void doGet(HttpServletRequest request, HttpServletResponse response)
		throws ServletException, IOException
	{
		
		final SessionControl sc = Base.getExistingSessionControl(request, true);
		JspContext context = ExtensionsControl.createContext(sc, null);
		
		ExtensionsInvoker<ExampleAction> invoker = (ExtensionsInvoker<ExampleAction>)ExtensionsControl.useExtensions(context, "net.sf.basedb.examples.extensions.custom-extension-point");
		
		PrintWriter out = response.getWriter();
		response.setContentType("text/plain");
		int numActions = 0;
		for (ExampleAction ea : invoker)
		{
			numActions++;
			out.print(numActions + ": " + ea.getName() + " (" + ea.getClass().getName() + ")\n");
		}
		
		out.print("---------------------\n");
		out.print("Found " + numActions + " action(s)\n");
		out.flush();
		out.close();
	}
	
}
